@@ -371,7 +371,6 @@ gdk_frame_clock_paint_idle (void *data)
               g_signal_emit_by_name (G_OBJECT (clock), "before-paint");
               priv->phase = GDK_FRAME_CLOCK_PHASE_UPDATE;
             }
-          /* fallthrough */
         case GDK_FRAME_CLOCK_PHASE_UPDATE:
           if (priv->freeze_count == 0)
             {
@@ -382,10 +381,10 @@ gdk_frame_clock_paint_idle (void *data)
                   g_signal_emit_by_name (G_OBJECT (clock), "update");
                 }
             }
-          /* fallthrough */
         case GDK_FRAME_CLOCK_PHASE_LAYOUT:
           if (priv->freeze_count == 0)
             {
+	      int iter;
 #ifdef G_ENABLE_DEBUG
               if ((_gdk_debug_flags & GDK_DEBUG_FRAMES) != 0)
                 {
@@ -396,13 +395,21 @@ gdk_frame_clock_paint_idle (void *data)
 #endif /* G_ENABLE_DEBUG */
 
               priv->phase = GDK_FRAME_CLOCK_PHASE_LAYOUT;
-              if (priv->requested & GDK_FRAME_CLOCK_PHASE_LAYOUT)
+	      /* We loop in the layout phase, because we don't want to progress
+	       * into the paint phase with invalid size allocations. This may
+	       * happen in some situation like races between user window
+	       * resizes and natural size changes.
+	       */
+	      iter = 0;
+              while ((priv->requested & GDK_FRAME_CLOCK_PHASE_LAYOUT) &&
+		     priv->freeze_count == 0 && iter++ < 4)
                 {
                   priv->requested &= ~GDK_FRAME_CLOCK_PHASE_LAYOUT;
                   g_signal_emit_by_name (G_OBJECT (clock), "layout");
                 }
+	      if (iter == 5)
+		g_warning ("gdk-frame-clock: layout continuously requested, giving up after 4 tries");
             }
-          /* fallthrough */
         case GDK_FRAME_CLOCK_PHASE_PAINT:
           if (priv->freeze_count == 0)
             {
@@ -422,7 +429,6 @@ gdk_frame_clock_paint_idle (void *data)
                   g_signal_emit_by_name (G_OBJECT (clock), "paint");
                 }
             }
-          /* fallthrough */
         case GDK_FRAME_CLOCK_PHASE_AFTER_PAINT:
           if (priv->freeze_count == 0)
             {
@@ -437,7 +443,6 @@ gdk_frame_clock_paint_idle (void *data)
                 timings->frame_end_time = g_get_monotonic_time ();
 #endif /* G_ENABLE_DEBUG */
             }
-          /* fallthrough */
         case GDK_FRAME_CLOCK_PHASE_RESUME_EVENTS:
           ;
         }
