@@ -98,42 +98,64 @@ gtk_css_value_shadows_transition (GtkCssValue *start,
                                   guint        property_id,
                                   double       progress)
 {
-  GtkCssValue *result;
-  guint i;
+  guint i, len;
+  GtkCssValue **values;
 
   /* catches the important case of 2 none values */
   if (start == end)
     return _gtk_css_value_ref (start);
 
   if (start->len > end->len)
-    result = gtk_css_shadows_value_new (start->values, start->len);
+    len = start->len;
   else
-    result = gtk_css_shadows_value_new (end->values, end->len);
+    len = end->len;
+
+  values = g_newa (GtkCssValue *, len);
 
   for (i = 0; i < MIN (start->len, end->len); i++)
     {
-      result->values[i] = _gtk_css_value_transition (start->values[i], end->values[i], property_id, progress);
+      values[i] = _gtk_css_value_transition (start->values[i], end->values[i], property_id, progress);
+      if (values[i] == NULL)
+        {
+          while (i--)
+            _gtk_css_value_unref (values[i]);
+          return NULL;
+        }
     }
   if (start->len > end->len)
     {
-      for (; i < result->len; i++)
+      for (; i < len; i++)
         {
           GtkCssValue *fill = _gtk_css_shadow_value_new_for_transition (start->values[i]);
-          result->values[i] = _gtk_css_value_transition (start->values[i], fill, property_id, progress);
+          values[i] = _gtk_css_value_transition (start->values[i], fill, property_id, progress);
           _gtk_css_value_unref (fill);
+
+          if (values[i] == NULL)
+            {
+              while (i--)
+                _gtk_css_value_unref (values[i]);
+              return NULL;
+            }
         }
     }
   else
     {
-      for (; i < result->len; i++)
+      for (; i < len; i++)
         {
           GtkCssValue *fill = _gtk_css_shadow_value_new_for_transition (end->values[i]);
-          result->values[i] = _gtk_css_value_transition (fill, end->values[i], property_id, progress);
+          values[i] = _gtk_css_value_transition (fill, end->values[i], property_id, progress);
           _gtk_css_value_unref (fill);
+
+          if (values[i] == NULL)
+            {
+              while (i--)
+                _gtk_css_value_unref (values[i]);
+              return NULL;
+            }
         }
     }
 
-  return result;
+  return gtk_css_shadows_value_new (values, len);
 }
 
 static void
@@ -265,7 +287,8 @@ _gtk_css_shadows_value_paint_spinner (const GtkCssValue *shadows,
 void
 _gtk_css_shadows_value_paint_box (const GtkCssValue   *shadows,
                                   cairo_t             *cr,
-                                  const GtkRoundedBox *padding_box)
+                                  const GtkRoundedBox *padding_box,
+                                  gboolean             inset)
 {
   guint i;
 
@@ -273,6 +296,41 @@ _gtk_css_shadows_value_paint_box (const GtkCssValue   *shadows,
 
   for (i = 0; i < shadows->len; i++)
     {
-      _gtk_css_shadow_value_paint_box (shadows->values[i], cr, padding_box);
+      if (inset == _gtk_css_shadow_value_get_inset (shadows->values[i]))
+        _gtk_css_shadow_value_paint_box (shadows->values[i], cr, padding_box);
+    }
+}
+
+void
+_gtk_css_shadows_value_get_extents (const GtkCssValue *shadows,
+                                    GtkBorder         *border)
+{
+  guint i;
+  GtkBorder b = { 0 };
+  const GtkCssValue *shadow;
+  gdouble hoffset, voffset, spread, radius;
+
+  g_return_if_fail (shadows->class == &GTK_CSS_VALUE_SHADOWS);
+
+  for (i = 0; i < shadows->len; i++)
+    {
+      shadow = shadows->values[i];
+
+      if (_gtk_css_shadow_value_get_inset (shadow))
+        continue;
+
+      _gtk_css_shadow_value_get_geometry (shadow,
+                                          &hoffset, &voffset,
+                                          &radius, &spread);
+
+      b.top = MAX (0, radius + spread - voffset);
+      b.right = MAX (0, radius + spread + hoffset);
+      b.bottom = MAX (0, radius + spread + voffset);
+      b.left = MAX (0, radius + spread - hoffset);
+
+      border->top = MAX (border->top, b.top);
+      border->right = MAX (border->right, b.right);
+      border->bottom = MAX (border->bottom, b.bottom);
+      border->left = MAX (border->left, b.left);
     }
 }
