@@ -130,7 +130,10 @@ enum
   LAST_SIGNAL
 };
 
-/* TreeModel Columns */
+/* TreeModel Columns
+ *
+ * keep in line with the store defined in gtkfilechooserbutton.ui
+ */
 enum
 {
   ICON_COLUMN,
@@ -182,14 +185,14 @@ struct _GtkFileChooserButtonPrivate
   GFile *selection_while_inactive;
   GFile *current_folder_while_inactive;
 
-  gulong combo_box_changed_id;
   gulong fs_volumes_changed_id;
-  gulong fs_bookmarks_changed_id;
 
   GCancellable *dnd_select_folder_cancellable;
   GCancellable *update_button_cancellable;
   GSList *change_icon_theme_cancellables;
 
+  GtkBookmarksManager *bookmarks_manager;
+
   gint icon_size;
 
   guint8 n_special;
@@ -321,8 +324,7 @@ static void          update_label_and_image       (GtkFileChooserButton *button)
 /* Child Object Callbacks */
 static void     fs_volumes_changed_cb            (GtkFileSystem  *fs,
 						  gpointer        user_data);
-static void     fs_bookmarks_changed_cb          (GtkFileSystem  *fs,
-						  gpointer        user_data);
+static void     bookmarks_changed_cb             (gpointer        user_data);
 
 static void     combo_box_changed_cb             (GtkComboBox    *combo_box,
 						  gpointer        user_data);
@@ -465,6 +467,23 @@ gtk_file_chooser_button_class_init (GtkFileChooserButtonClass * class)
 
   _gtk_file_chooser_install_properties (gobject_class);
 
+  /* Bind class to template
+   */
+  gtk_widget_class_set_template_from_resource (widget_class,
+					       "/org/gtk/libgtk/gtkfilechooserbutton.ui");
+
+  gtk_widget_class_bind_child (widget_class, GtkFileChooserButtonPrivate, model);
+  gtk_widget_class_bind_child (widget_class, GtkFileChooserButtonPrivate, button);
+  gtk_widget_class_bind_child (widget_class, GtkFileChooserButtonPrivate, image);
+  gtk_widget_class_bind_child (widget_class, GtkFileChooserButtonPrivate, label);
+  gtk_widget_class_bind_child (widget_class, GtkFileChooserButtonPrivate, combo_box);
+  gtk_widget_class_bind_child (widget_class, GtkFileChooserButtonPrivate, icon_cell);
+  gtk_widget_class_bind_child (widget_class, GtkFileChooserButtonPrivate, name_cell);
+
+  gtk_widget_class_bind_callback (widget_class, button_clicked_cb);
+  gtk_widget_class_bind_callback (widget_class, combo_box_changed_cb);
+  gtk_widget_class_bind_callback (widget_class, combo_box_notify_popup_shown_cb);
+
   g_type_class_add_private (class, sizeof (GtkFileChooserButtonPrivate));
 }
 
@@ -472,7 +491,6 @@ static void
 gtk_file_chooser_button_init (GtkFileChooserButton *button)
 {
   GtkFileChooserButtonPrivate *priv;
-  GtkWidget *box, *image, *sep;
   GtkTargetList *target_list;
 
   priv = button->priv = G_TYPE_INSTANCE_GET_PRIVATE (button,
@@ -482,78 +500,14 @@ gtk_file_chooser_button_init (GtkFileChooserButton *button)
   priv->icon_size = FALLBACK_ICON_SIZE;
   priv->focus_on_click = TRUE;
 
-  gtk_widget_push_composite_child ();
+  gtk_widget_init_template (GTK_WIDGET (button));
 
-  /* Button */
-  priv->button = gtk_button_new ();
-  g_signal_connect (priv->button, "clicked",
-                    G_CALLBACK (button_clicked_cb), button);
-  gtk_box_pack_start (GTK_BOX (button), priv->button, TRUE, TRUE, 0);
-  gtk_widget_set_halign (priv->button, GTK_ALIGN_FILL);
-  gtk_widget_show (priv->button);
-
-  box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
-  gtk_container_add (GTK_CONTAINER (priv->button), box);
-  gtk_widget_show (box);
-
-  priv->image = gtk_image_new ();
-  gtk_box_pack_start (GTK_BOX (box), priv->image, FALSE, FALSE, 0);
-  gtk_widget_show (priv->image);
-
-  priv->label = gtk_label_new (_(FALLBACK_DISPLAY_NAME));
-  gtk_label_set_ellipsize (GTK_LABEL (priv->label), PANGO_ELLIPSIZE_END);
-  gtk_widget_set_halign (priv->label, GTK_ALIGN_START);
-  gtk_widget_set_valign (priv->label, GTK_ALIGN_CENTER);
-  gtk_box_pack_start (GTK_BOX (box), priv->label, TRUE, TRUE, 0);
-  //gtk_container_add (GTK_CONTAINER (box), priv->label);
-  gtk_widget_show (priv->label);
-
-  sep = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
-  gtk_box_pack_start (GTK_BOX (box), sep, FALSE, FALSE, 0);
-  gtk_widget_show (sep);
-
-  image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
-  gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
-  gtk_widget_show (image);
-
-  /* Combo Box */
-  /* Keep in sync with columns enum, line 88 */
-  priv->model =
-    GTK_TREE_MODEL (gtk_list_store_new (NUM_COLUMNS,
-					GDK_TYPE_PIXBUF, /* ICON_COLUMN */
-					G_TYPE_STRING,	 /* DISPLAY_NAME_COLUMN */
-					G_TYPE_CHAR,	 /* TYPE_COLUMN */
-					G_TYPE_POINTER	 /* DATA_COLUMN (Volume || Path) */,
-					G_TYPE_BOOLEAN   /* IS_FOLDER_COLUMN */,
-					G_TYPE_POINTER	 /* CANCELLABLE_COLUMN */));
-
-  priv->combo_box = gtk_combo_box_new ();
-  priv->combo_box_changed_id = g_signal_connect (priv->combo_box, "changed",
-						 G_CALLBACK (combo_box_changed_cb), button);
-
-  g_signal_connect (priv->combo_box, "notify::popup-shown",
-		    G_CALLBACK (combo_box_notify_popup_shown_cb), button);
-
-  gtk_box_pack_start (GTK_BOX (button), priv->combo_box, TRUE, TRUE, 0);
-  gtk_widget_set_halign (priv->combo_box, GTK_ALIGN_FILL);
-
-  priv->icon_cell = gtk_cell_renderer_pixbuf_new ();
-  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->combo_box),
-			      priv->icon_cell, FALSE);
-  gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (priv->combo_box),
-				 priv->icon_cell, "pixbuf", ICON_COLUMN);
-
-  priv->name_cell = gtk_cell_renderer_text_new ();
-  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->combo_box),
-			      priv->name_cell, TRUE);
-  gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (priv->combo_box),
-				 priv->name_cell, "text", DISPLAY_NAME_COLUMN);
+  /* Bookmarks manager */
+  priv->bookmarks_manager = _gtk_bookmarks_manager_new (bookmarks_changed_cb, button);
   gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (priv->combo_box),
 				      priv->name_cell, name_cell_data_func,
 				      NULL, NULL);
 
-  gtk_widget_pop_composite_child ();
-
   /* DnD */
   gtk_drag_dest_set (GTK_WIDGET (button),
                      (GTK_DEST_DEFAULT_ALL),
@@ -897,7 +851,7 @@ gtk_file_chooser_button_constructor (GType                  type,
   model_add_volumes (button, list);
   g_slist_free (list);
 
-  list = _gtk_file_system_list_bookmarks (priv->fs);
+  list = _gtk_bookmarks_manager_list_bookmarks (priv->bookmarks_manager);
   model_add_bookmarks (button, list);
   g_slist_foreach (list, (GFunc) g_object_unref, NULL);
   g_slist_free (list);
@@ -926,9 +880,6 @@ gtk_file_chooser_button_constructor (GType                  type,
   priv->fs_volumes_changed_id =
     g_signal_connect (priv->fs, "volumes-changed",
 		      G_CALLBACK (fs_volumes_changed_cb), object);
-  priv->fs_bookmarks_changed_id =
-    g_signal_connect (priv->fs, "bookmarks-changed",
-		      G_CALLBACK (fs_bookmarks_changed_cb), object);
 
   update_label_and_image (button);
   update_combo_box (button);
@@ -1012,7 +963,7 @@ gtk_file_chooser_button_set_property (GObject      *object,
     case GTK_FILE_CHOOSER_PROP_LOCAL_ONLY:
       g_object_set_property (G_OBJECT (priv->dialog), pspec->name, value);
       fs_volumes_changed_cb (priv->fs, button);
-      fs_bookmarks_changed_cb (priv->fs, button);
+      bookmarks_changed_cb (button);
       break;
 
     case GTK_FILE_CHOOSER_PROP_SELECT_MULTIPLE:
@@ -1128,12 +1079,6 @@ gtk_file_chooser_button_destroy (GtkWidget *widget)
       priv->change_icon_theme_cancellables = NULL;
     }
 
-  if (priv->model)
-    {
-      g_object_unref (priv->model);
-      priv->model = NULL;
-    }
-
   if (priv->filter_model)
     {
       g_object_unref (priv->filter_model);
@@ -1143,11 +1088,16 @@ gtk_file_chooser_button_destroy (GtkWidget *widget)
   if (priv->fs)
     {
       g_signal_handler_disconnect (priv->fs, priv->fs_volumes_changed_id);
-      g_signal_handler_disconnect (priv->fs, priv->fs_bookmarks_changed_id);
       g_object_unref (priv->fs);
       priv->fs = NULL;
     }
 
+  if (priv->bookmarks_manager)
+    {
+      _gtk_bookmarks_manager_free (priv->bookmarks_manager);
+      priv->bookmarks_manager = NULL;
+    }
+
   GTK_WIDGET_CLASS (gtk_file_chooser_button_parent_class)->destroy (widget);
 }
 
@@ -1658,7 +1608,7 @@ set_info_for_file_at_iter (GtkFileChooserButton *button,
 
   data = g_new0 (struct SetDisplayNameData, 1);
   data->button = g_object_ref (button);
-  data->label = _gtk_file_system_get_bookmark_label (button->priv->fs, file);
+  data->label = _gtk_bookmarks_manager_get_bookmark_label (button->priv->bookmarks_manager, file);
 
   tree_path = gtk_tree_model_get_path (button->priv->model, iter);
   data->row_ref = gtk_tree_row_reference_new (button->priv->model, tree_path);
@@ -2042,7 +1992,7 @@ model_add_bookmarks (GtkFileChooserButton *button,
 	   * If we switch to a better bookmarks file format (XBEL), we
 	   * should use mime info to get a better icon.
 	   */
-	  label = _gtk_file_system_get_bookmark_label (button->priv->fs, file);
+	  label = _gtk_bookmarks_manager_get_bookmark_label (button->priv->bookmarks_manager, file);
 	  if (!label)
 	    label = _gtk_file_chooser_label_for_file (file);
 
@@ -2145,7 +2095,7 @@ model_update_current_folder (GtkFileChooserButton *button,
        * If we switch to a better bookmarks file format (XBEL), we
        * should use mime info to get a better icon.
        */
-      label = _gtk_file_system_get_bookmark_label (button->priv->fs, file);
+      label = _gtk_bookmarks_manager_get_bookmark_label (button->priv->bookmarks_manager, file);
       if (!label)
 	label = _gtk_file_chooser_label_for_file (file);
 
@@ -2402,9 +2352,9 @@ select_combo_box_row_no_notify (GtkFileChooserButton *button, int pos)
   gtk_tree_model_filter_convert_child_iter_to_iter (GTK_TREE_MODEL_FILTER (priv->filter_model),
 						    &filter_iter, &iter);
 
-  g_signal_handler_block (priv->combo_box, priv->combo_box_changed_id);
+  g_signal_handlers_block_by_func (priv->combo_box, combo_box_changed_cb, button);
   gtk_combo_box_set_active_iter (GTK_COMBO_BOX (priv->combo_box), &filter_iter);
-  g_signal_handler_unblock (priv->combo_box, priv->combo_box_changed_id);
+  g_signal_handlers_unblock_by_func (priv->combo_box, combo_box_changed_cb, button);
 }
 
 static void
@@ -2461,11 +2411,10 @@ update_combo_box (GtkFileChooserButton *button)
 
       if (row_found)
 	{
-	  g_signal_handler_block (priv->combo_box, priv->combo_box_changed_id);
+	  g_signal_handlers_block_by_func (priv->combo_box, combo_box_changed_cb, button);
 	  gtk_combo_box_set_active_iter (GTK_COMBO_BOX (priv->combo_box),
 					 &iter);
-	  g_signal_handler_unblock (priv->combo_box,
-				    priv->combo_box_changed_id);
+	  g_signal_handlers_unblock_by_func (priv->combo_box, combo_box_changed_cb, button);
 	}
     }
   while (!row_found && gtk_tree_model_iter_next (priv->filter_model, &iter));
@@ -2603,7 +2552,7 @@ update_label_and_image (GtkFileChooserButton *button)
         {
           GdkPixbuf *pixbuf;
 
-          label_text = _gtk_file_system_get_bookmark_label (button->priv->fs, file);
+          label_text = _gtk_bookmarks_manager_get_bookmark_label (button->priv->bookmarks_manager, file);
           pixbuf = gtk_icon_theme_load_icon (get_icon_theme (GTK_WIDGET (priv->image)),
                                              "text-x-generic",
                                              priv->icon_size, 0, NULL);
@@ -2671,14 +2620,13 @@ fs_volumes_changed_cb (GtkFileSystem *fs,
 }
 
 static void
-fs_bookmarks_changed_cb (GtkFileSystem *fs,
-			 gpointer       user_data)
+bookmarks_changed_cb (gpointer user_data)
 {
   GtkFileChooserButton *button = GTK_FILE_CHOOSER_BUTTON (user_data);
   GtkFileChooserButtonPrivate *priv = button->priv;
   GSList *bookmarks;
 
-  bookmarks = _gtk_file_system_list_bookmarks (fs);
+  bookmarks = _gtk_bookmarks_manager_list_bookmarks (priv->bookmarks_manager);
   model_remove_rows (user_data,
 		     model_get_type_position (user_data,
 					      ROW_TYPE_BOOKMARK_SEPARATOR),
@@ -2764,15 +2712,12 @@ static void
 combo_box_changed_cb (GtkComboBox *combo_box,
 		      gpointer     user_data)
 {
-  GtkFileChooserButton *button = GTK_FILE_CHOOSER_BUTTON (user_data);
-  GtkFileChooserButtonPrivate *priv = button->priv;
   GtkTreeIter iter;
-  gboolean file_was_set;
-
-  file_was_set = FALSE;
 
   if (gtk_combo_box_get_active_iter (combo_box, &iter))
     {
+      GtkFileChooserButton *button = GTK_FILE_CHOOSER_BUTTON (user_data);
+      GtkFileChooserButtonPrivate *priv = button->priv;
       gchar type;
       gpointer data;
 
@@ -2791,10 +2736,7 @@ combo_box_changed_cb (GtkComboBox *combo_box,
 	case ROW_TYPE_BOOKMARK:
 	case ROW_TYPE_CURRENT_FOLDER:
 	  if (data)
-	    {
-	      gtk_file_chooser_button_select_file (GTK_FILE_CHOOSER (button), data, NULL);
-	      file_was_set = TRUE;
-	    }
+	    gtk_file_chooser_button_select_file (GTK_FILE_CHOOSER (button), data, NULL);
 	  break;
 	case ROW_TYPE_VOLUME:
 	  {
@@ -2804,7 +2746,6 @@ combo_box_changed_cb (GtkComboBox *combo_box,
 	    if (base_file)
 	      {
 		gtk_file_chooser_button_select_file (GTK_FILE_CHOOSER (button), base_file, NULL);
-		file_was_set = TRUE;
 		g_object_unref (base_file);
 	      }
 	  }
@@ -2816,9 +2757,6 @@ combo_box_changed_cb (GtkComboBox *combo_box,
 	  break;
 	}
     }
-
-  if (file_was_set)
-    g_signal_emit (button, file_chooser_button_signals[FILE_SET], 0);
 }
 
 /* Calback for the "notify::popup-shown" signal on the combo box.
