@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -25,14 +23,14 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
-#error "Only <gtk/gtk.h> can be included directly."
-#endif
-
 #ifndef __GTK_NOTEBOOK_H__
 #define __GTK_NOTEBOOK_H__
 
 
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
 #include <gtk/gtkcontainer.h>
 
 
@@ -124,31 +122,40 @@ struct _GtkNotebookClass
  *           Creation, insertion, deletion                 *
  ***********************************************************/
 
+GDK_AVAILABLE_IN_ALL
 GType   gtk_notebook_get_type       (void) G_GNUC_CONST;
+GDK_AVAILABLE_IN_ALL
 GtkWidget * gtk_notebook_new        (void);
+GDK_AVAILABLE_IN_ALL
 gint gtk_notebook_append_page       (GtkNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label);
+GDK_AVAILABLE_IN_ALL
 gint gtk_notebook_append_page_menu  (GtkNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     GtkWidget   *menu_label);
+GDK_AVAILABLE_IN_ALL
 gint gtk_notebook_prepend_page      (GtkNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label);
+GDK_AVAILABLE_IN_ALL
 gint gtk_notebook_prepend_page_menu (GtkNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     GtkWidget   *menu_label);
+GDK_AVAILABLE_IN_ALL
 gint gtk_notebook_insert_page       (GtkNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     gint         position);
+GDK_AVAILABLE_IN_ALL
 gint gtk_notebook_insert_page_menu  (GtkNotebook *notebook,
 				     GtkWidget   *child,
 				     GtkWidget   *tab_label,
 				     GtkWidget   *menu_label,
 				     gint         position);
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_remove_page       (GtkNotebook *notebook,
 				     gint         page_num);
 
@@ -156,8 +163,10 @@ void gtk_notebook_remove_page       (GtkNotebook *notebook,
  *           Tabs drag and drop                            *
  ***********************************************************/
 
+GDK_AVAILABLE_IN_ALL
 void         gtk_notebook_set_group_name (GtkNotebook *notebook,
                                           const gchar *group_name);
+GDK_AVAILABLE_IN_ALL
 const gchar *gtk_notebook_get_group_name (GtkNotebook *notebook);
 
 
@@ -166,83 +175,117 @@ const gchar *gtk_notebook_get_group_name (GtkNotebook *notebook);
  *            query, set current NotebookPage              *
  ***********************************************************/
 
+GDK_AVAILABLE_IN_ALL
 gint       gtk_notebook_get_current_page (GtkNotebook *notebook);
+GDK_AVAILABLE_IN_ALL
 GtkWidget* gtk_notebook_get_nth_page     (GtkNotebook *notebook,
 					  gint         page_num);
+GDK_AVAILABLE_IN_ALL
 gint       gtk_notebook_get_n_pages      (GtkNotebook *notebook);
+GDK_AVAILABLE_IN_ALL
 gint       gtk_notebook_page_num         (GtkNotebook *notebook,
 					  GtkWidget   *child);
+GDK_AVAILABLE_IN_ALL
 void       gtk_notebook_set_current_page (GtkNotebook *notebook,
 					  gint         page_num);
+GDK_AVAILABLE_IN_ALL
 void       gtk_notebook_next_page        (GtkNotebook *notebook);
+GDK_AVAILABLE_IN_ALL
 void       gtk_notebook_prev_page        (GtkNotebook *notebook);
 
 /***********************************************************
  *            set Notebook, NotebookTab style              *
  ***********************************************************/
 
+GDK_AVAILABLE_IN_ALL
 void     gtk_notebook_set_show_border      (GtkNotebook     *notebook,
 					    gboolean         show_border);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_notebook_get_show_border      (GtkNotebook     *notebook);
+GDK_AVAILABLE_IN_ALL
 void     gtk_notebook_set_show_tabs        (GtkNotebook     *notebook,
 					    gboolean         show_tabs);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_notebook_get_show_tabs        (GtkNotebook     *notebook);
+GDK_AVAILABLE_IN_ALL
 void     gtk_notebook_set_tab_pos          (GtkNotebook     *notebook,
 				            GtkPositionType  pos);
+GDK_AVAILABLE_IN_ALL
 GtkPositionType gtk_notebook_get_tab_pos   (GtkNotebook     *notebook);
+GDK_AVAILABLE_IN_ALL
 void     gtk_notebook_set_scrollable       (GtkNotebook     *notebook,
 					    gboolean         scrollable);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_notebook_get_scrollable       (GtkNotebook     *notebook);
+GDK_AVAILABLE_IN_ALL
 guint16  gtk_notebook_get_tab_hborder      (GtkNotebook     *notebook);
+GDK_AVAILABLE_IN_ALL
 guint16  gtk_notebook_get_tab_vborder      (GtkNotebook     *notebook);
 
 /***********************************************************
  *               enable/disable PopupMenu                  *
  ***********************************************************/
 
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_popup_enable  (GtkNotebook *notebook);
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_popup_disable (GtkNotebook *notebook);
 
 /***********************************************************
  *             query/set NotebookPage Properties           *
  ***********************************************************/
 
+GDK_AVAILABLE_IN_ALL
 GtkWidget * gtk_notebook_get_tab_label    (GtkNotebook *notebook,
 					   GtkWidget   *child);
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_set_tab_label           (GtkNotebook *notebook,
 					   GtkWidget   *child,
 					   GtkWidget   *tab_label);
+GDK_AVAILABLE_IN_ALL
 void          gtk_notebook_set_tab_label_text (GtkNotebook *notebook,
                                                GtkWidget   *child,
                                                const gchar *tab_text);
+GDK_AVAILABLE_IN_ALL
 const gchar * gtk_notebook_get_tab_label_text (GtkNotebook *notebook,
                                                GtkWidget   *child);
+GDK_AVAILABLE_IN_ALL
 GtkWidget * gtk_notebook_get_menu_label   (GtkNotebook *notebook,
 					   GtkWidget   *child);
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_set_menu_label          (GtkNotebook *notebook,
 					   GtkWidget   *child,
 					   GtkWidget   *menu_label);
+GDK_AVAILABLE_IN_ALL
 void          gtk_notebook_set_menu_label_text (GtkNotebook *notebook,
                                                 GtkWidget   *child,
                                                 const gchar *menu_text);
+GDK_AVAILABLE_IN_ALL
 const gchar * gtk_notebook_get_menu_label_text (GtkNotebook *notebook,
 							GtkWidget   *child);
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_reorder_child           (GtkNotebook *notebook,
 					   GtkWidget   *child,
 					   gint         position);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_notebook_get_tab_reorderable (GtkNotebook *notebook,
 					   GtkWidget   *child);
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_set_tab_reorderable     (GtkNotebook *notebook,
 					   GtkWidget   *child,
 					   gboolean     reorderable);
+GDK_AVAILABLE_IN_ALL
 gboolean gtk_notebook_get_tab_detachable  (GtkNotebook *notebook,
 					   GtkWidget   *child);
+GDK_AVAILABLE_IN_ALL
 void gtk_notebook_set_tab_detachable      (GtkNotebook *notebook,
 					   GtkWidget   *child,
 					   gboolean     detachable);
 
+GDK_AVAILABLE_IN_ALL
 GtkWidget* gtk_notebook_get_action_widget (GtkNotebook *notebook,
                                            GtkPackType  pack_type);
+GDK_AVAILABLE_IN_ALL
 void       gtk_notebook_set_action_widget (GtkNotebook *notebook,
                                            GtkWidget   *widget,
                                            GtkPackType  pack_type);
