@@ -143,7 +143,8 @@ gtk_overlay_create_child_window (GtkOverlay *overlay,
   attributes.height = allocation.height;
   attributes.x = allocation.x;
   attributes.y = allocation.y;
-  attributes_mask = GDK_WA_X | GDK_WA_Y;
+  attributes.visual = gtk_widget_get_visual (widget);
+  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL;
   attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
 
   window = gdk_window_new (gtk_widget_get_window (widget),
