@@ -24,31 +24,25 @@
 
 /* The extra size of the offscreen surface we allocate
    to make scrolling more efficient */
-#define DEFAULT_EXTRA_SIZE 64
+#define EXTRA_SIZE 64
 
-/* When resizing viewport we allow this extra
+/* When resizing viewport to smaller we allow this extra
    size to avoid constantly reallocating when resizing */
-#define ALLOW_SMALLER_SIZE 32
 #define ALLOW_LARGER_SIZE 32
 
 struct _GtkPixelCache {
   cairo_surface_t *surface;
-  cairo_content_t content;
 
   /* Valid if surface != NULL */
   int surface_x;
   int surface_y;
   int surface_w;
   int surface_h;
-  double surface_scale;
 
   /* may be null if not dirty */
   cairo_region_t *surface_dirty;
 
   guint timeout_tag;
-
-  guint extra_width;
-  guint extra_height;
 };
 
 GtkPixelCache *
@@ -57,8 +51,6 @@ _gtk_pixel_cache_new ()
   GtkPixelCache *cache;
 
   cache = g_new0 (GtkPixelCache, 1);
-  cache->extra_width = DEFAULT_EXTRA_SIZE;
-  cache->extra_height = DEFAULT_EXTRA_SIZE;
 
   return cache;
 }
@@ -81,35 +73,6 @@ _gtk_pixel_cache_free (GtkPixelCache *cache)
   g_free (cache);
 }
 
-void
-_gtk_pixel_cache_set_extra_size (GtkPixelCache *cache,
-                                 guint          extra_width,
-                                 guint          extra_height)
-{
-  cache->extra_width = extra_width ? extra_width : DEFAULT_EXTRA_SIZE;
-  cache->extra_height = extra_height ? extra_height : DEFAULT_EXTRA_SIZE;
-}
-
-void
-_gtk_pixel_cache_get_extra_size (GtkPixelCache *cache,
-                                 guint         *extra_width,
-                                 guint         *extra_height)
-{
-  if (extra_width)
-    *extra_width = cache->extra_width;
-
-  if (extra_height)
-    *extra_height = cache->extra_height;
-}
-
-void
-_gtk_pixel_cache_set_content (GtkPixelCache   *cache,
-			      cairo_content_t  content)
-{
-  cache->content = content;
-  _gtk_pixel_cache_invalidate (cache, NULL);
-}
-
 /* Region is in canvas coordinates */
 void
 _gtk_pixel_cache_invalidate (GtkPixelCache *cache,
@@ -174,39 +137,29 @@ _gtk_pixel_cache_create_surface_if_needed (GtkPixelCache         *cache,
   cairo_pattern_t *bg;
   double red, green, blue, alpha;
 
-#ifdef G_ENABLE_DEBUG
-  if (gtk_get_debug_flags () & GTK_DEBUG_NO_PIXEL_CACHE)
-    return;
-#endif
-
-  content = cache->content;
-  if (!content)
-    {
-      content = CAIRO_CONTENT_COLOR_ALPHA;
-      bg = gdk_window_get_background_pattern (window);
-      if (bg != NULL &&
-          cairo_pattern_get_type (bg) == CAIRO_PATTERN_TYPE_SOLID &&
-          cairo_pattern_get_rgba (bg, &red, &green, &blue, &alpha) == CAIRO_STATUS_SUCCESS &&
-          alpha == 1.0)
-        content = CAIRO_CONTENT_COLOR;
-    }
+  content = CAIRO_CONTENT_COLOR_ALPHA;
+  bg = gdk_window_get_background_pattern (window);
+  if (bg != NULL &&
+      cairo_pattern_get_type (bg) == CAIRO_PATTERN_TYPE_SOLID &&
+      cairo_pattern_get_rgba (bg, &red, &green, &blue, &alpha) == CAIRO_STATUS_SUCCESS &&
+      alpha == 1.0)
+    content = CAIRO_CONTENT_COLOR;
 
   surface_w = view_rect->width;
   if (canvas_rect->width > surface_w)
-    surface_w = MIN (surface_w + cache->extra_width, canvas_rect->width);
+    surface_w = MIN (surface_w + EXTRA_SIZE, canvas_rect->width);
 
   surface_h = view_rect->height;
   if (canvas_rect->height > surface_h)
-    surface_h = MIN (surface_h + cache->extra_height, canvas_rect->height);
+    surface_h = MIN (surface_h + EXTRA_SIZE, canvas_rect->height);
 
   /* If current surface can't fit view_rect or is too large, kill it */
   if (cache->surface != NULL &&
       (cairo_surface_get_content (cache->surface) != content ||
-       cache->surface_w < MAX(view_rect->width, surface_w - ALLOW_SMALLER_SIZE) ||
+       cache->surface_w < view_rect->width ||
        cache->surface_w > surface_w + ALLOW_LARGER_SIZE ||
-       cache->surface_h < MAX(view_rect->height, surface_h - ALLOW_SMALLER_SIZE) ||
-       cache->surface_h > surface_h + ALLOW_LARGER_SIZE ||
-       cache->surface_scale != gdk_window_get_scale_factor (window)))
+       cache->surface_h < view_rect->height ||
+       cache->surface_h > surface_h + ALLOW_LARGER_SIZE))
     {
       cairo_surface_destroy (cache->surface);
       cache->surface = NULL;
@@ -225,7 +178,6 @@ _gtk_pixel_cache_create_surface_if_needed (GtkPixelCache         *cache,
       cache->surface_y = -canvas_rect->y;
       cache->surface_w = surface_w;
       cache->surface_h = surface_h;
-      cache->surface_scale = gdk_window_get_scale_factor (window);
 
       cache->surface =
 	gdk_window_create_similar_surface (window, content,
@@ -327,15 +279,13 @@ _gtk_pixel_cache_repaint (GtkPixelCache *cache,
 			  gpointer user_data)
 {
   cairo_t *backing_cr;
-  cairo_region_t *region_dirty = cache->surface_dirty;
-  cache->surface_dirty = NULL;
 
   if (cache->surface &&
-      region_dirty &&
-      !cairo_region_is_empty (region_dirty))
+      cache->surface_dirty &&
+      !cairo_region_is_empty (cache->surface_dirty))
     {
       backing_cr = cairo_create (cache->surface);
-      gdk_cairo_region (backing_cr, region_dirty);
+      gdk_cairo_region (backing_cr, cache->surface_dirty);
       cairo_clip (backing_cr);
       cairo_translate (backing_cr,
 		       -cache->surface_x - canvas_rect->x - view_rect->x,
@@ -372,8 +322,11 @@ _gtk_pixel_cache_repaint (GtkPixelCache *cache,
       cairo_destroy (backing_cr);
     }
 
-  if (region_dirty)
-    cairo_region_destroy (region_dirty);
+  if (cache->surface_dirty)
+    {
+      cairo_region_destroy (cache->surface_dirty);
+      cache->surface_dirty = NULL;
+    }
 }
 
 static gboolean
