@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * Copyright 2013, 2015 Red Hat, Inc.
+ * Copyright (c) 2013 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -17,7 +17,7 @@
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Author: Alexander Larsson <alexl@redhat.com>
- *         Carlos Soriano <csoriano@gnome.org>
+ *
  */
 
 #include "config.h"
@@ -25,11 +25,8 @@
 #include <gdk/gdk.h>
 #include "gtktypebuiltins.h"
 #include "gtkprivate.h"
-#include "gtksettingsprivate.h"
-#include "gtkprogresstrackerprivate.h"
 #include "gtkintl.h"
-
-#include "fallback-c89.c"
+#include <math.h>
 
 /**
  * SECTION:gtkrevealer
@@ -43,13 +40,6 @@
  * The style of transition can be controlled with
  * gtk_revealer_set_transition_type().
  *
- * These animations respect the #GtkSettings:gtk-enable-animations
- * setting.
- *
- * # CSS nodes
- *
- * GtkRevealer has a single CSS node with name revealer.
- *
  * The GtkRevealer widget was added in GTK+ 3.10.
  */
 
@@ -71,11 +61,10 @@ enum  {
   PROP_TRANSITION_TYPE,
   PROP_TRANSITION_DURATION,
   PROP_REVEAL_CHILD,
-  PROP_CHILD_REVEALED,
-  LAST_PROP
+  PROP_CHILD_REVEALED
 };
 
-typedef struct {
+struct _GtkRevealerPrivate {
   GtkRevealerTransitionType transition_type;
   guint transition_duration;
 
@@ -87,15 +76,16 @@ typedef struct {
   gdouble target_pos;
 
   guint tick_id;
-  GtkProgressTracker tracker;
-} GtkRevealerPrivate;
+  gint64 start_time;
+  gint64 end_time;
+};
 
-static GParamSpec *props[LAST_PROP] = { NULL, };
 
 static void     gtk_revealer_real_realize                        (GtkWidget     *widget);
 static void     gtk_revealer_real_unrealize                      (GtkWidget     *widget);
 static void     gtk_revealer_real_add                            (GtkContainer  *widget,
                                                                   GtkWidget     *child);
+static void     gtk_revealer_real_style_updated                  (GtkWidget     *widget);
 static void     gtk_revealer_real_size_allocate                  (GtkWidget     *widget,
                                                                   GtkAllocation *allocation);
 static void     gtk_revealer_real_map                            (GtkWidget     *widget);
@@ -117,26 +107,16 @@ static void     gtk_revealer_real_get_preferred_width_for_height (GtkWidget
                                                                   gint          *minimum_width,
                                                                   gint          *natural_width);
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtkRevealer, gtk_revealer, GTK_TYPE_BIN)
+G_DEFINE_TYPE (GtkRevealer, gtk_revealer, GTK_TYPE_BIN);
 
-static void
-gtk_revealer_get_padding (GtkRevealer *revealer,
-                          GtkBorder   *padding)
-{
-  GtkWidget *widget = GTK_WIDGET (revealer);
-  GtkStyleContext *context;
-  GtkStateFlags state;
-
-  context = gtk_widget_get_style_context (widget);
-  state = gtk_style_context_get_state (context);
-
-  gtk_style_context_get_padding (context, state, padding);
-}
 
 static void
 gtk_revealer_init (GtkRevealer *revealer)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv;
+
+  priv = G_TYPE_INSTANCE_GET_PRIVATE (revealer, GTK_TYPE_REVEALER, GtkRevealerPrivate);
+  revealer->priv = priv;
 
   priv->transition_type = GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN;
   priv->transition_duration = 250;
@@ -144,13 +124,14 @@ gtk_revealer_init (GtkRevealer *revealer)
   priv->target_pos = 0.0;
 
   gtk_widget_set_has_window ((GtkWidget*) revealer, TRUE);
+  gtk_widget_set_redraw_on_allocate ((GtkWidget*) revealer, FALSE);
 }
 
 static void
 gtk_revealer_finalize (GObject *obj)
 {
   GtkRevealer *revealer = GTK_REVEALER (obj);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
 
   if (priv->tick_id != 0)
     gtk_widget_remove_tick_callback (GTK_WIDGET (revealer), priv->tick_id);
@@ -225,6 +206,7 @@ gtk_revealer_class_init (GtkRevealerClass *klass)
 
   widget_class->realize = gtk_revealer_real_realize;
   widget_class->unrealize = gtk_revealer_real_unrealize;
+  widget_class->style_updated = gtk_revealer_real_style_updated;
   widget_class->size_allocate = gtk_revealer_real_size_allocate;
   widget_class->map = gtk_revealer_real_map;
   widget_class->unmap = gtk_revealer_real_unmap;
@@ -236,49 +218,42 @@ gtk_revealer_class_init (GtkRevealerClass *klass)
 
   container_class->add = gtk_revealer_real_add;
 
-  props[PROP_TRANSITION_TYPE] =
-    g_param_spec_enum ("transition-type",
-                       P_("Transition type"),
-                       P_("The type of animation used to transition"),
-                       GTK_TYPE_REVEALER_TRANSITION_TYPE,
-                       GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN,
-                       GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_EXPLICIT_NOTIFY);
+  g_object_class_install_property (object_class,
+                                   PROP_TRANSITION_TYPE,
+                                   g_param_spec_enum ("transition-type",
+                                                      P_("Transition type"),
+                                                      P_("The type of animation used to transition"),
+                                                      GTK_TYPE_REVEALER_TRANSITION_TYPE,
+                                                      GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN,
+                                                      GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
-  props[PROP_TRANSITION_DURATION] =
-    g_param_spec_uint ("transition-duration",
-                       P_("Transition duration"),
-                       P_("The animation duration, in milliseconds"),
-                       0, G_MAXUINT, 250,
-                       GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_EXPLICIT_NOTIFY);
+  g_object_class_install_property (object_class,
+                                   PROP_TRANSITION_DURATION,
+                                   g_param_spec_uint ("transition-duration",
+                                                      P_("Transition duration"),
+                                                      P_("The animation duration, in milliseconds"),
+                                                      0, G_MAXUINT,
+                                                      250,
+                                                      GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+  g_object_class_install_property (object_class,
+                                   PROP_REVEAL_CHILD,
+                                   g_param_spec_boolean ("reveal-child",
+                                                         P_("Reveal Child"),
+                                                         P_("Whether the container should reveal the child"),
+                                                         FALSE,
+                                                         GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
-  props[PROP_REVEAL_CHILD] =
-    g_param_spec_boolean ("reveal-child",
-                          P_("Reveal Child"),
-                          P_("Whether the container should reveal the child"),
-                          FALSE,
-                          GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_EXPLICIT_NOTIFY);
+  g_object_class_install_property (object_class,
+                                   PROP_CHILD_REVEALED,
+                                   g_param_spec_boolean ("child-revealed",
+                                                         P_("Child Revealed"),
+                                                         P_("Whether the child is revealed and the animation target reached"),
+                                                         FALSE,
+                                                         G_PARAM_READABLE));
 
-  props[PROP_CHILD_REVEALED] =
-    g_param_spec_boolean ("child-revealed",
-                          P_("Child Revealed"),
-                          P_("Whether the child is revealed and the animation target reached"),
-                          FALSE,
-                          G_PARAM_READABLE);
-
-  g_object_class_install_properties (object_class, LAST_PROP, props);
-
-  gtk_widget_class_set_css_name (widget_class, "revealer");
+  g_type_class_add_private (klass, sizeof (GtkRevealerPrivate));
 }
 
-/**
- * gtk_revealer_new:
- *
- * Creates a new #GtkRevealer.
- *
- * Returns: a newly created #GtkRevealer
- *
- * Since: 3.10
- */
 GtkWidget *
 gtk_revealer_new (void)
 {
@@ -288,7 +263,7 @@ gtk_revealer_new (void)
 static GtkRevealerTransitionType
 effective_transition (GtkRevealer *revealer)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
 
   if (gtk_widget_get_direction (GTK_WIDGET (revealer)) == GTK_TEXT_DIR_RTL)
     {
@@ -308,21 +283,14 @@ gtk_revealer_get_child_allocation (GtkRevealer   *revealer,
 {
   GtkWidget *child;
   GtkRevealerTransitionType transition;
-  GtkBorder padding;
-  gint vertical_padding, horizontal_padding;
 
   g_return_if_fail (revealer != NULL);
   g_return_if_fail (allocation != NULL);
 
-  /* See explanation on gtk_revealer_real_size_allocate */
-  gtk_revealer_get_padding (revealer, &padding);
-  vertical_padding = padding.top + padding.bottom;
-  horizontal_padding = padding.left + padding.right;
-
   child_allocation->x = 0;
   child_allocation->y = 0;
-  child_allocation->width = 0;
-  child_allocation->height = 0;
+  child_allocation->width = allocation->width;
+  child_allocation->height = allocation->height;
 
   child = gtk_bin_get_child (GTK_BIN (revealer));
   if (child != NULL && gtk_widget_get_visible (child))
@@ -330,29 +298,26 @@ gtk_revealer_get_child_allocation (GtkRevealer   *revealer,
       transition = effective_transition (revealer);
       if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT ||
           transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT)
-        gtk_widget_get_preferred_width_for_height (child, MAX (0, allocation->height - vertical_padding), NULL,
+        gtk_widget_get_preferred_width_for_height (child, child_allocation->height, NULL,
                                                    &child_allocation->width);
       else
-        gtk_widget_get_preferred_height_for_width (child, MAX (0, allocation->width - horizontal_padding), NULL,
+        gtk_widget_get_preferred_height_for_width (child, child_allocation->width, NULL,
                                                    &child_allocation->height);
     }
-
-  child_allocation->width = MAX (child_allocation->width, allocation->width - horizontal_padding);
-  child_allocation->height = MAX (child_allocation->height, allocation->height - vertical_padding);
 }
 
 static void
 gtk_revealer_real_realize (GtkWidget *widget)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
   GtkAllocation allocation;
   GdkWindowAttr attributes = { 0 };
   GdkWindowAttributesType attributes_mask;
   GtkAllocation child_allocation;
   GtkWidget *child;
+  GtkStyleContext *context;
   GtkRevealerTransitionType transition;
-  GtkBorder padding;
 
   gtk_widget_set_realized (widget, TRUE);
 
@@ -366,7 +331,7 @@ gtk_revealer_real_realize (GtkWidget *widget)
   attributes.wclass = GDK_INPUT_OUTPUT;
   attributes.visual = gtk_widget_get_visual (widget);
   attributes.event_mask =
-    gtk_widget_get_events (widget);
+    gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
   attributes_mask = (GDK_WA_X | GDK_WA_Y) | GDK_WA_VISUAL;
 
   priv->view_window =
@@ -377,29 +342,16 @@ gtk_revealer_real_realize (GtkWidget *widget)
 
   gtk_revealer_get_child_allocation (revealer, &allocation, &child_allocation);
 
-  gtk_revealer_get_padding (revealer, &padding);
   attributes.x = 0;
   attributes.y = 0;
   attributes.width = child_allocation.width;
   attributes.height = child_allocation.height;
 
-  /* See explanation on gtk_revealer_real_size_allocate */
   transition = effective_transition (revealer);
   if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN)
-    {
-      attributes.y = allocation.height - child_allocation.height - padding.bottom;
-      attributes.x = padding.left;
-    }
+    attributes.y = allocation.height - child_allocation.height;
   else if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT)
-    {
-      attributes.y = padding.top;
-      attributes.x = allocation.width - child_allocation.width - padding.right;
-    }
- else
-   {
-     attributes.y = padding.top;
-     attributes.x = padding.left;
-   }
+    attributes.x = allocation.width - child_allocation.width;
 
   priv->bin_window =
     gdk_window_new (priv->view_window, &attributes, attributes_mask);
@@ -409,6 +361,9 @@ gtk_revealer_real_realize (GtkWidget *widget)
   if (child != NULL)
     gtk_widget_set_parent_window (child, priv->bin_window);
 
+  context = gtk_widget_get_style_context (widget);
+  gtk_style_context_set_background (context, priv->view_window);
+  gtk_style_context_set_background (context, priv->bin_window);
   gdk_window_show (priv->bin_window);
 }
 
@@ -416,7 +371,7 @@ static void
 gtk_revealer_real_unrealize (GtkWidget *widget)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
 
   gtk_widget_unregister_window (widget, priv->bin_window);
   gdk_window_destroy (priv->bin_window);
@@ -430,7 +385,7 @@ gtk_revealer_real_add (GtkContainer *container,
                        GtkWidget    *child)
 {
   GtkRevealer *revealer = GTK_REVEALER (container);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
 
   g_return_if_fail (child != NULL);
 
@@ -440,18 +395,34 @@ gtk_revealer_real_add (GtkContainer *container,
   GTK_CONTAINER_CLASS (gtk_revealer_parent_class)->add (container, child);
 }
 
+static void
+gtk_revealer_real_style_updated (GtkWidget *widget)
+{
+  GtkRevealer *revealer = GTK_REVEALER (widget);
+  GtkRevealerPrivate *priv = revealer->priv;
+  GtkStyleContext* context;
+
+  GTK_WIDGET_CLASS (gtk_revealer_parent_class)->style_updated (widget);
+
+  if (gtk_widget_get_realized (widget))
+    {
+      context = gtk_widget_get_style_context (widget);
+      gtk_style_context_set_background (context, priv->bin_window);
+      gtk_style_context_set_background (context, priv->view_window);
+    }
+}
+
 static void
 gtk_revealer_real_size_allocate (GtkWidget     *widget,
                                  GtkAllocation *allocation)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
   GtkAllocation child_allocation;
   GtkWidget *child;
   gboolean window_visible;
   int bin_x, bin_y;
   GtkRevealerTransitionType transition;
-  GtkBorder padding;
 
   g_return_if_fail (allocation != NULL);
 
@@ -475,54 +446,17 @@ gtk_revealer_real_size_allocate (GtkWidget     *widget,
             gdk_window_show (priv->view_window);
         }
 
-      /* The view window will follow the revealer allocation, which is modified
-       * along the animation */
       gdk_window_move_resize (priv->view_window,
                               allocation->x, allocation->y,
                               allocation->width, allocation->height);
 
-      gtk_revealer_get_padding (revealer, &padding);
       bin_x = 0;
       bin_y = 0;
-
       transition = effective_transition (revealer);
-      /* The child allocation is fixed (it is not modified by the animation),
-       * and it's origin is relative to the bin_window.
-       * The bin_window has the same allocation as the child, and then the bin_window
-       * deals with the relative positioning with respect to the revealer taking
-       * into account the paddings of the revealer.
-       *
-       * For most of transitions, the bin_window moves along with the revealer,
-       * as its allocation changes.
-       * However for GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN
-       * we need to first move the bin_window upwards and then slide it down in
-       * the revealer.
-       * Otherwise the child would appear as static and the revealer will allocate
-       * following the animation, clipping the child.
-       * To calculate the correct y position for this case:
-       * allocation->height - child_allocation.height is the relative position
-       * towards the revealer taking into account the animation progress with
-       * both vertical paddings added, therefore we need to substract the part
-       * that we don't want to take into account for the y position, which
-       * in this case is the bottom padding.
-       *
-       * The same special treatment is needed for GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT.
-       */
       if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN)
-        {
-          bin_y = allocation->height - child_allocation.height - padding.bottom;
-          bin_x = padding.left;
-        }
+        bin_y = allocation->height - child_allocation.height;
       else if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT)
-        {
-          bin_y = padding.top;
-          bin_x = allocation->width - child_allocation.width - padding.right;
-        }
-     else
-       {
-         bin_x = padding.left;
-         bin_y = padding.top;
-       }
+        bin_x = allocation->width - child_allocation.width;
 
       gdk_window_move_resize (priv->bin_window,
                               bin_x, bin_y,
@@ -534,7 +468,7 @@ static void
 gtk_revealer_set_position (GtkRevealer *revealer,
                            gdouble      pos)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
   gboolean new_visible;
   GtkWidget *child;
   GtkRevealerTransitionType transition;
@@ -565,25 +499,43 @@ gtk_revealer_set_position (GtkRevealer *revealer,
     }
 
   if (priv->current_pos == priv->target_pos)
-    g_object_notify_by_pspec (G_OBJECT (revealer), props[PROP_CHILD_REVEALED]);
+    g_object_notify (G_OBJECT (revealer), "child-revealed");
+}
+
+static gdouble
+ease_out_quad (gdouble t, gdouble d)
+{
+  gdouble p = t / d;
+  return  ((-1.0) * p) * (p - 2);
+}
+
+static void
+gtk_revealer_animate_step (GtkRevealer *revealer,
+                           gint64       now)
+{
+  GtkRevealerPrivate *priv = revealer->priv;
+  gdouble t;
+
+  t = 1.0;
+  if (now < priv->end_time)
+      t = (now - priv->start_time) / (gdouble) (priv->end_time - priv->start_time);
+  t = ease_out_quad (t, 1.0);
+
+  gtk_revealer_set_position (revealer,
+                            priv->source_pos + (t * (priv->target_pos - priv->source_pos)));
 }
 
 static gboolean
-gtk_revealer_animate_cb (GtkWidget     *widget,
+gtk_revealer_animate_cb (GtkRevealer   *revealer,
                          GdkFrameClock *frame_clock,
                          gpointer       user_data)
 {
-  GtkRevealer *revealer = GTK_REVEALER (widget);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-  gdouble ease;
+  GtkRevealerPrivate *priv = revealer->priv;
+  gint64 now;
 
-  gtk_progress_tracker_advance_frame (&priv->tracker,
-                                      gdk_frame_clock_get_frame_time (frame_clock));
-  ease = gtk_progress_tracker_get_ease_out_cubic (&priv->tracker, FALSE);
-  gtk_revealer_set_position (revealer,
-                             priv->source_pos + (ease * (priv->target_pos - priv->source_pos)));
-
-  if (gtk_progress_tracker_get_state (&priv->tracker) == GTK_PROGRESS_STATE_AFTER)
+  now = gdk_frame_clock_get_frame_time (frame_clock);
+  gtk_revealer_animate_step (revealer, now);
+  if (priv->current_pos == priv->target_pos)
     {
       priv->tick_id = 0;
       return FALSE;
@@ -596,7 +548,7 @@ static void
 gtk_revealer_start_animation (GtkRevealer *revealer,
                               gdouble      target)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
   GtkWidget *widget = GTK_WIDGET (revealer);
   GtkRevealerTransitionType transition;
 
@@ -604,22 +556,20 @@ gtk_revealer_start_animation (GtkRevealer *revealer,
     return;
 
   priv->target_pos = target;
-  g_object_notify_by_pspec (G_OBJECT (revealer), props[PROP_REVEAL_CHILD]);
+  g_object_notify (G_OBJECT (revealer), "reveal-child");
 
   transition = effective_transition (revealer);
   if (gtk_widget_get_mapped (widget) &&
       priv->transition_duration != 0 &&
-      transition != GTK_REVEALER_TRANSITION_TYPE_NONE &&
-      gtk_settings_get_enable_animations (gtk_widget_get_settings (widget)))
+      transition != GTK_REVEALER_TRANSITION_TYPE_NONE)
     {
       priv->source_pos = priv->current_pos;
+      priv->start_time = gdk_frame_clock_get_frame_time (gtk_widget_get_frame_clock (widget));
+      priv->end_time = priv->start_time + (priv->transition_duration * 1000);
       if (priv->tick_id == 0)
         priv->tick_id =
-          gtk_widget_add_tick_callback (widget, gtk_revealer_animate_cb, revealer, NULL);
-      gtk_progress_tracker_start (&priv->tracker,
-                                  priv->transition_duration * 1000,
-                                  0,
-                                  1.0);
+          gtk_widget_add_tick_callback (widget, (GtkTickCallback)gtk_revealer_animate_cb, revealer, NULL);
+      gtk_revealer_animate_step (revealer, priv->start_time);
     }
   else
     {
@@ -630,9 +580,9 @@ gtk_revealer_start_animation (GtkRevealer *revealer,
 static void
 gtk_revealer_stop_animation (GtkRevealer *revealer)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-  if (priv->current_pos != priv->target_pos)
-    gtk_revealer_set_position (revealer, priv->target_pos);
+  GtkRevealerPrivate *priv = revealer->priv;
+
+  priv->current_pos = priv->target_pos;
   if (priv->tick_id != 0)
     {
       gtk_widget_remove_tick_callback (GTK_WIDGET (revealer), priv->tick_id);
@@ -644,7 +594,7 @@ static void
 gtk_revealer_real_map (GtkWidget *widget)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
   GtkAllocation allocation;
 
   if (!gtk_widget_get_mapped (widget))
@@ -653,6 +603,8 @@ gtk_revealer_real_map (GtkWidget *widget)
 
       if (allocation.width > 0 && allocation.height > 0)
         gdk_window_show (priv->view_window);
+
+      gtk_revealer_start_animation (revealer, priv->target_pos);
     }
 
   GTK_WIDGET_CLASS (gtk_revealer_parent_class)->map (widget);
@@ -673,12 +625,12 @@ gtk_revealer_real_draw (GtkWidget *widget,
                         cairo_t   *cr)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
+  GtkRevealerPrivate *priv = revealer->priv;
 
   if (gtk_cairo_should_draw_window (cr, priv->bin_window))
     GTK_WIDGET_CLASS (gtk_revealer_parent_class)->draw (widget, cr);
 
-  return GDK_EVENT_PROPAGATE;
+  return TRUE;
 }
 
 /**
@@ -717,36 +669,33 @@ gtk_revealer_set_reveal_child (GtkRevealer *revealer,
  * the child is fully revealed (ie the transition is completed),
  * use gtk_revealer_get_child_revealed().
  *
- * Returns: %TRUE if the child is revealed.
+ * Return value: %TRUE if the child is revealed.
  *
  * Since: 3.10
  */
 gboolean
 gtk_revealer_get_reveal_child (GtkRevealer *revealer)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-
   g_return_val_if_fail (GTK_IS_REVEALER (revealer), FALSE);
 
-  return priv->target_pos != 0.0;
+  return revealer->priv->target_pos != 0.0;
 }
 
 /**
  * gtk_revealer_get_child_revealed:
  * @revealer: a #GtkRevealer
  *
- * Returns whether the child is fully revealed, in other words whether
+ * Returns whether the child is fully revealed, ie wether
  * the transition to the revealed state is completed.
  *
- * Returns: %TRUE if the child is fully revealed
+ * Return value: %TRUE if the child is fully revealed
  *
  * Since: 3.10
  */
 gboolean
 gtk_revealer_get_child_revealed (GtkRevealer *revealer)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-  gboolean animation_finished = (priv->target_pos == priv->current_pos);
+  gboolean animation_finished = (revealer->priv->target_pos == revealer->priv->current_pos);
   gboolean reveal_child = gtk_revealer_get_reveal_child (revealer);
 
   if (animation_finished)
@@ -761,52 +710,30 @@ gtk_revealer_get_child_revealed (GtkRevealer *revealer)
  * re-arranging itself during the animation).
  */
 
-static void
-set_height_with_paddings (GtkRevealer *revealer,
-                          gint         preferred_minimum_height,
-                          gint         preferred_natural_height,
-                          gint        *minimum_height_out,
-                          gint        *natural_height_out)
-{
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-  gint minimum_height;
-  gint natural_height;
-  GtkRevealerTransitionType transition;
-  GtkBorder padding;
-  gint vertical_padding;
-
-  gtk_revealer_get_padding (revealer, &padding);
-  vertical_padding = padding.top + padding.bottom;
-  minimum_height = preferred_minimum_height + vertical_padding;
-  natural_height = preferred_natural_height + vertical_padding;
-
-  transition = effective_transition (revealer);
-  if (transition == GTK_REVEALER_TRANSITION_TYPE_NONE ||
-      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP ||
-      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN)
-    {
-      /* Padding are included in the animation */
-      minimum_height = round (minimum_height * priv->current_pos);
-      natural_height = round (natural_height * priv->current_pos);
-    }
-
-  *minimum_height_out = MIN (minimum_height, natural_height);
-  *natural_height_out = natural_height;
-}
-
 static void
 gtk_revealer_real_get_preferred_height (GtkWidget *widget,
                                         gint      *minimum_height_out,
                                         gint      *natural_height_out)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
+  GtkRevealerPrivate *priv = revealer->priv;
   gint minimum_height;
   gint natural_height;
+  GtkRevealerTransitionType transition;
 
   GTK_WIDGET_CLASS (gtk_revealer_parent_class)->get_preferred_height (widget, &minimum_height, &natural_height);
 
-  set_height_with_paddings (revealer, minimum_height, natural_height,
-                            minimum_height_out, natural_height_out);
+  transition = effective_transition (revealer);
+  if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP ||
+      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN)
+    natural_height = round (natural_height * priv->current_pos);
+
+  minimum_height = natural_height;
+
+  if (minimum_height_out)
+    *minimum_height_out = minimum_height;
+  if (natural_height_out)
+    *natural_height_out = natural_height;
 }
 
 static void
@@ -816,46 +743,24 @@ gtk_revealer_real_get_preferred_height_for_width (GtkWidget *widget,
                                                   gint      *natural_height_out)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
+  GtkRevealerPrivate *priv = revealer->priv;
   gint minimum_height;
   gint natural_height;
+  GtkRevealerTransitionType transition;
 
   GTK_WIDGET_CLASS (gtk_revealer_parent_class)->get_preferred_height_for_width (widget, width, &minimum_height, &natural_height);
 
-  set_height_with_paddings (revealer, minimum_height, natural_height,
-                            minimum_height_out, natural_height_out);
-}
-
-static void
-set_width_with_paddings (GtkRevealer *revealer,
-                         gint         preferred_minimum_width,
-                         gint         preferred_natural_width,
-                         gint        *minimum_width_out,
-                         gint        *natural_width_out)
-{
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-  gint minimum_width;
-  gint natural_width;
-  GtkRevealerTransitionType transition;
-  GtkBorder padding;
-  gint horizontal_padding;
-
-  gtk_revealer_get_padding (revealer, &padding);
-  horizontal_padding = padding.left + padding.right;
-  minimum_width = preferred_minimum_width + horizontal_padding;
-  natural_width = preferred_natural_width + horizontal_padding;
-
   transition = effective_transition (revealer);
-  if (transition == GTK_REVEALER_TRANSITION_TYPE_NONE ||
-      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT ||
-      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT)
-    {
-      /* Paddings are included in the animation */
-      minimum_width = round (minimum_width * priv->current_pos);
-      natural_width = round (natural_width * priv->current_pos);
-    }
+  if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP ||
+      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN)
+    natural_height = round (natural_height * priv->current_pos);
 
-  *minimum_width_out = MIN (minimum_width, natural_width);
-  *natural_width_out = natural_width;
+  minimum_height = natural_height;
+
+  if (minimum_height_out)
+    *minimum_height_out = minimum_height;
+  if (natural_height_out)
+    *natural_height_out = natural_height;
 }
 
 static void
@@ -864,12 +769,24 @@ gtk_revealer_real_get_preferred_width (GtkWidget *widget,
                                        gint      *natural_width_out)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
+  GtkRevealerPrivate *priv = revealer->priv;
   gint minimum_width;
   gint natural_width;
+  GtkRevealerTransitionType transition;
 
   GTK_WIDGET_CLASS (gtk_revealer_parent_class)->get_preferred_width (widget, &minimum_width, &natural_width);
-  set_width_with_paddings (revealer, minimum_width, natural_width,
-                           minimum_width_out, natural_width_out);
+
+  transition = effective_transition (revealer);
+  if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT ||
+      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT)
+    natural_width = round (natural_width * priv->current_pos);
+
+  minimum_width = natural_width;
+
+  if (minimum_width_out)
+    *minimum_width_out = minimum_width;
+  if (natural_width_out)
+    *natural_width_out = natural_width;
 }
 
 static void
@@ -879,13 +796,24 @@ gtk_revealer_real_get_preferred_width_for_height (GtkWidget *widget,
                                                   gint      *natural_width_out)
 {
   GtkRevealer *revealer = GTK_REVEALER (widget);
+  GtkRevealerPrivate *priv = revealer->priv;
   gint minimum_width;
   gint natural_width;
+  GtkRevealerTransitionType transition;
 
   GTK_WIDGET_CLASS (gtk_revealer_parent_class)->get_preferred_width_for_height (widget, height, &minimum_width, &natural_width);
 
-  set_width_with_paddings (revealer, minimum_width, natural_width,
-                           minimum_width_out, natural_width_out);
+  transition = effective_transition (revealer);
+  if (transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT ||
+      transition == GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT)
+    natural_width = round (natural_width * priv->current_pos);
+
+  minimum_width = natural_width;
+
+  if (minimum_width_out)
+    *minimum_width_out = minimum_width;
+  if (natural_width_out)
+    *natural_width_out = natural_width;
 }
 
 /**
@@ -902,11 +830,9 @@ gtk_revealer_real_get_preferred_width_for_height (GtkWidget *widget,
 guint
 gtk_revealer_get_transition_duration (GtkRevealer *revealer)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-
   g_return_val_if_fail (GTK_IS_REVEALER (revealer), 0);
 
-  return priv->transition_duration;
+  return revealer->priv->transition_duration;
 }
 
 /**
@@ -922,15 +848,10 @@ void
 gtk_revealer_set_transition_duration (GtkRevealer *revealer,
                                       guint        value)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-
   g_return_if_fail (GTK_IS_REVEALER (revealer));
 
-  if (priv->transition_duration == value)
-    return;
-
-  priv->transition_duration = value;
-  g_object_notify_by_pspec (G_OBJECT (revealer), props[PROP_TRANSITION_DURATION]);
+  revealer->priv->transition_duration = value;
+  g_object_notify (G_OBJECT (revealer), "transition-duration");
 }
 
 /**
@@ -940,18 +861,16 @@ gtk_revealer_set_transition_duration (GtkRevealer *revealer,
  * Gets the type of animation that will be used
  * for transitions in @revealer.
  *
- * Returns: the current transition type of @revealer
+ * Return value: the current transition type of @revealer
  *
  * Since: 3.10
  */
 GtkRevealerTransitionType
 gtk_revealer_get_transition_type (GtkRevealer *revealer)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-
   g_return_val_if_fail (GTK_IS_REVEALER (revealer), GTK_REVEALER_TRANSITION_TYPE_NONE);
 
-  return priv->transition_type;
+  return revealer->priv->transition_type;
 }
 
 /**
@@ -969,14 +888,9 @@ void
 gtk_revealer_set_transition_type (GtkRevealer               *revealer,
                                   GtkRevealerTransitionType  transition)
 {
-  GtkRevealerPrivate *priv = gtk_revealer_get_instance_private (revealer);
-
   g_return_if_fail (GTK_IS_REVEALER (revealer));
 
-  if (priv->transition_type == transition)
-    return;
-
-  priv->transition_type = transition;
+  revealer->priv->transition_type = transition;
   gtk_widget_queue_resize (GTK_WIDGET (revealer));
-  g_object_notify_by_pspec (G_OBJECT (revealer), props[PROP_TRANSITION_TYPE]);
+  g_object_notify (G_OBJECT (revealer), "transition-type");
 }
