@@ -209,6 +209,7 @@ struct GtkThemingModuleClass
 #define GTK_THEMING_MODULE(o)    (G_TYPE_CHECK_INSTANCE_CAST ((o), GTK_TYPE_THEMING_MODULE, GtkThemingModule))
 #define GTK_IS_THEMING_MODULE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTK_TYPE_THEMING_MODULE))
 
+_GDK_EXTERN
 GType gtk_theming_module_get_type (void);
 
 G_DEFINE_TYPE (GtkThemingModule, gtk_theming_module, G_TYPE_TYPE_MODULE);
@@ -277,7 +278,7 @@ gtk_theming_engine_finalize (GObject *object)
   priv = GTK_THEMING_ENGINE (object)->priv;
   g_free (priv->name);
 
-  G_OBJECT_GET_CLASS (gtk_theming_engine_parent_class)->finalize (object);
+  G_OBJECT_CLASS (gtk_theming_engine_parent_class)->finalize (object);
 }
 
 static void
