@@ -1,6 +1,7 @@
 
 /* Generated data (by glib-mkenums) */
 
+#include "config.h"
 #include "gtk.h"
 #include "gtkprivate.h"
 
@@ -244,6 +245,7 @@ gtk_debug_flag_get_type (void)
             { GTK_DEBUG_SIZE_REQUEST, "GTK_DEBUG_SIZE_REQUEST", "size-request" },
             { GTK_DEBUG_NO_CSS_CACHE, "GTK_DEBUG_NO_CSS_CACHE", "no-css-cache" },
             { GTK_DEBUG_BASELINES, "GTK_DEBUG_BASELINES", "baselines" },
+            { GTK_DEBUG_PIXEL_CACHE, "GTK_DEBUG_PIXEL_CACHE", "pixel-cache" },
             { 0, NULL, NULL }
         };
         etype = g_flags_register_static (g_intern_static_string ("GtkDebugFlag"), values);
