@@ -13,7 +13,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * $Id:$
  */
@@ -25,10 +27,7 @@
 #include "gtk/gtkintl.h"
 #include "gtk/gtkimmodule.h"
 
-#define GTK_COMPILATION 1 // For gdkquartz-gtk-only.h
-
-#include "gdk/quartz/gdkinternal-quartz.h"
-#include "gdk/quartz/gdkquartz-gtk-only.h"
+#include "gdk/quartz/gdkquartz.h"
 #include "gdk/quartz/GdkQuartzView.h"
 
 #define GTK_IM_CONTEXT_TYPE_QUARTZ (type_quartz)
@@ -58,7 +57,7 @@ static GObjectClass *parent_class;
 static const GtkIMContextInfo imquartz_info =
 {
   "quartz",
-  NC_("input method menu", "Mac OS X Quartz"),
+  "Mac OS X Quartz",
   GETTEXT_PACKAGE,
   GTK_LOCALEDIR,
   "ja:ko:zh:*",
@@ -127,31 +126,53 @@ quartz_get_preedit_string (GtkIMContext *context,
 }
 
 static gboolean
-output_result (GtkIMContext *context,
-               GdkWindow *win)
+quartz_filter_keypress (GtkIMContext *context,
+                        GdkEventKey *event)
 {
   GtkIMContextQuartz *qc = GTK_IM_CONTEXT_QUARTZ (context);
   gboolean retval = FALSE;
-  int fixed_str_replace_len;
+  NSView *nsview;
+  GdkWindow *win;
   gchar *fixed_str, *marked_str;
 
-  fixed_str_replace_len = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (win),
-      TIC_INSERT_TEXT_REPLACE_LEN));
-  fixed_str = g_strdup (g_object_get_data (G_OBJECT (win), TIC_INSERT_TEXT));
-  marked_str = g_strdup (g_object_get_data (G_OBJECT (win), TIC_MARKED_TEXT));
+  GTK_NOTE (MISC, g_print ("quartz_filter_keypress\n"));
+
+  if (event->type == GDK_KEY_RELEASE)
+    return FALSE;
+
+  if (!qc->client_window)
+    return FALSE;
+
+  nsview = gdk_quartz_window_get_nsview (qc->client_window);
+  if (GDK_IS_WINDOW (nsview))
+       /* it gets GDK_WINDOW in some cases */
+    return gtk_im_context_filter_keypress (qc->slave, event);
+  else
+    win = (GdkWindow *)[ (GdkQuartzView *)nsview gdkWindow];
+  GTK_NOTE (MISC, g_print ("client_window: %p, win: %p, nsview: %p\n",
+			   qc->client_window, win, nsview));
+
+  if (event->hardware_keycode == 55)	/* Command */
+    return FALSE;
+
+  NSEvent *nsevent = gdk_quartz_event_get_nsevent ((GdkEvent *)event);
+  NSEventType etype = [nsevent type];
+  if (etype == NSKeyDown)
+       [nsview keyDown: nsevent];
+  /* JIS_Eisu || JIS_Kana */
+  if (event->hardware_keycode == 102 || event->hardware_keycode == 104)
+    return FALSE;
+
+  GTK_NOTE (MISC,
+	    g_print ("quartz_filter_keypress: getting tic-insert-text\n"));
+  fixed_str = g_object_get_data (G_OBJECT (win), TIC_INSERT_TEXT);
+  marked_str = g_object_get_data (G_OBJECT (win), TIC_MARKED_TEXT);
   if (fixed_str)
     {
       GTK_NOTE (MISC, g_print ("tic-insert-text: %s\n", fixed_str));
       g_free (qc->preedit_str);
       qc->preedit_str = NULL;
       g_object_set_data (G_OBJECT (win), TIC_INSERT_TEXT, NULL);
-      if (fixed_str_replace_len)
-        {
-          gboolean retval;
-          g_object_set_data (G_OBJECT (win), TIC_INSERT_TEXT_REPLACE_LEN, 0);
-          g_signal_emit_by_name (context, "delete-surrounding",
-              -fixed_str_replace_len, fixed_str_replace_len, &retval);
-        }
       g_signal_emit_by_name (context, "commit", fixed_str);
       g_signal_emit_by_name (context, "preedit_changed");
 
@@ -179,115 +200,17 @@ output_result (GtkIMContext *context,
       g_signal_emit_by_name (context, "preedit_changed");
       retval = TRUE;
     }
-  if (!fixed_str && !marked_str)
-    {
-      unsigned int filtered =
-	  GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (win),
-					       GIC_FILTER_KEY));
-      if (filtered)
-        retval = TRUE;
-      if (qc->preedit_str && strlen (qc->preedit_str) > 0)
-        retval = TRUE;
-    }
   g_free (fixed_str);
   g_free (marked_str);
-  return retval;
-}
 
-static gboolean
-quartz_filter_keypress (GtkIMContext *context,
-                        GdkEventKey *event)
-{
-  GtkIMContextQuartz *qc = GTK_IM_CONTEXT_QUARTZ (context);
-  gboolean retval;
-  NSView *nsview;
-  GdkWindow *win;
-
-  GTK_NOTE (MISC, g_print ("quartz_filter_keypress\n"));
-
-  if (!GDK_IS_QUARTZ_WINDOW (qc->client_window))
-    return FALSE;
-
-  NSEvent *nsevent = gdk_quartz_event_get_nsevent ((GdkEvent *)event);
-
-  if (!nsevent)
-    {
-      if (event->hardware_keycode == 0 && event->keyval == 0xffffff)
-        /* update text input changes by mouse events */
-        return output_result (context, event->window);
-      else
-        return gtk_im_context_filter_keypress (qc->slave, event);
-    }
-
-  nsview = gdk_quartz_window_get_nsview (qc->client_window);
-
-  win = (GdkWindow *)[(GdkQuartzView *)[[nsevent window] contentView] gdkWindow];
-  GTK_NOTE (MISC, g_print ("client_window: %p, win: %p, nsview: %p\n",
-                           qc->client_window, win, nsview));
-
-  if (event->type == GDK_KEY_RELEASE)
-    return FALSE;
-
-  if (event->hardware_keycode == 55)	/* Command */
-    return FALSE;
-
-  if (event->hardware_keycode == 53) /* Escape */
-    return FALSE;
-
-  NSEventType etype = [nsevent type];
-  if (etype == NSKeyDown)
-    {
-       g_object_set_data (G_OBJECT (win), TIC_IN_KEY_DOWN,
-                                          GUINT_TO_POINTER (TRUE));
-       [nsview keyDown: nsevent];
-    }
-  /* JIS_Eisu || JIS_Kana */
-  if (event->hardware_keycode == 102 || event->hardware_keycode == 104)
-    return FALSE;
-
-  retval = output_result(context, win);
-  g_object_set_data (G_OBJECT (win), TIC_IN_KEY_DOWN,
-                                     GUINT_TO_POINTER (FALSE));
   GTK_NOTE (MISC, g_print ("quartz_filter_keypress done\n"));
-
   return retval;
 }
 
-static void
-discard_preedit (GtkIMContext *context)
-{
-  GtkIMContextQuartz *qc = GTK_IM_CONTEXT_QUARTZ (context);
-
-  if (!qc->client_window)
-    return;
-
-  if (!GDK_IS_QUARTZ_WINDOW (qc->client_window))
-    return;
-
-  NSView *nsview = gdk_quartz_window_get_nsview (qc->client_window);
-  if (!nsview)
-    return;
-
-  /* reset any partial input for this NSView */
-  [(GdkQuartzView *)nsview unmarkText];
-  NSInputManager *currentInputManager = [NSInputManager currentInputManager];
-  [currentInputManager markedTextAbandoned:nsview];
-
-  if (qc->preedit_str && strlen (qc->preedit_str) > 0)
-    {
-      g_signal_emit_by_name (context, "commit", qc->preedit_str);
-
-      g_free (qc->preedit_str);
-      qc->preedit_str = NULL;
-      g_signal_emit_by_name (context, "preedit_changed");
-    }
-}
-
 static void
 quartz_reset (GtkIMContext *context)
 {
   GTK_NOTE (MISC, g_print ("quartz_reset\n"));
-  discard_preedit (context);
 }
 
 static void
@@ -316,9 +239,6 @@ quartz_focus_out (GtkIMContext *context)
 
   GtkIMContextQuartz *qc = GTK_IM_CONTEXT_QUARTZ (context);
   qc->focused = FALSE;
-
-  /* Commit any partially built strings or it'll mess up other GTK+ widgets in the window */
-  discard_preedit (context);
 }
 
 static void
@@ -347,10 +267,11 @@ quartz_set_cursor_location (GtkIMContext *context, GdkRectangle *area)
   qc->cursor_rect->x = area->x + x;
   qc->cursor_rect->y = area->y + y;
 
-  if (!GDK_IS_QUARTZ_WINDOW (qc->client_window))
+  nsview = gdk_quartz_window_get_nsview (qc->client_window);
+  if (GDK_IS_WINDOW (nsview))
+    /* it returns GDK_WINDOW in some cases */
     return;
 
-  nsview = gdk_quartz_window_get_nsview (qc->client_window);
   win = (GdkWindow *)[ (GdkQuartzView*)nsview gdkWindow];
   g_object_set_data (G_OBJECT (win), GIC_CURSOR_RECT, qc->cursor_rect);
 }
