@@ -20,7 +20,6 @@
 
 #include "config.h"
 
-#include <locale.h>
 #include <string.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
@@ -258,9 +257,7 @@ dump_text_attributes (GString         *string,
   for (l = attributes; l; l = l->next)
     {
       attr = l->data;
-      /* don't dump values that depend on the environment or too
-       * closely on the exact theme pixels.
-       */
+      /* don't dump values that depend on the environment */
       if (strcmp (attr->name, "family-name") == 0 ||
           strcmp (attr->name, "size") == 0 ||
           strcmp (attr->name, "weight") == 0 ||
@@ -427,63 +424,49 @@ dump_atk_value (AtkValue *atk_value,
                 guint     depth,
                 GString  *string)
 {
-  AtkRange *range;
-  gdouble value;
-  gchar *text;
-
-  value = 0.0;
-  text = NULL;
-
-  atk_value_get_value_and_text (atk_value, &value, &text);
-  range = atk_value_get_range (atk_value);
+  GValue value = G_VALUE_INIT;
+  GValue svalue = G_VALUE_INIT;
 
   g_string_append_printf (string, "%*s<AtkValue>\n", depth, "");
 
-  if (range)
-    {
-      g_string_append_printf (string, "%*sminimum value: %f\n", depth, "", atk_range_get_lower_limit (range));
+  g_value_init (&value, G_TYPE_DOUBLE);
+  g_value_init (&svalue, G_TYPE_STRING);
 
-      g_string_append_printf (string, "%*smaximum value: %f\n", depth, "", atk_range_get_upper_limit (range));
-
-      atk_range_free (range);
-    }
-
-  if (text)
-    {
-      g_string_append_printf (string, "%*scurrent value: %f %s\n", depth, "", value, text); 
-      g_free (text);
-    }
+  atk_value_get_minimum_value (atk_value, &value);
+  if (g_value_transform (&value, &svalue))
+    g_string_append_printf (string, "%*sminimum value: %s\n", depth, "", g_value_get_string (&svalue));
   else
-    g_string_append_printf (string, "%*scurrent value: %f\n", depth, "", value);
+    g_string_append_printf (string, "%*sminimum value: <%s>\n", depth, "", G_VALUE_TYPE_NAME (&value));
 
-  /* Don't dump minimum increment; it changes too much in response to
-   * theme changes.
-   * https://bugzilla.gnome.org/show_bug.cgi?id=704747
-   */
-}
+  g_value_reset (&value);
+  g_value_reset (&svalue);
 
-static void
-dump_atk_hyperlink (AtkHyperlink *link,
-                    guint         depth,
-                    GString      *string)
-{
-  gint i;
+  atk_value_get_maximum_value (atk_value, &value);
+  if (g_value_transform (&value, &svalue))
+    g_string_append_printf (string, "%*smaximum value: %s\n", depth, "", g_value_get_string (&svalue));
+  else
+    g_string_append_printf (string, "%*smaximum value: <%s>\n", depth, "", G_VALUE_TYPE_NAME (&value));
 
-  g_string_append_printf (string, "%*s<AtkHyperlink>\n", depth, "");
-  g_string_append_printf (string, "%*sstart index: %d\n", depth, "", atk_hyperlink_get_start_index (link));
-  g_string_append_printf (string, "%*send index: %d\n", depth, "", atk_hyperlink_get_end_index (link));
-  g_string_append_printf (string, "%*sanchors:", depth, "");
+  g_value_reset (&value);
+  g_value_reset (&svalue);
 
-  for (i = 0; i < atk_hyperlink_get_n_anchors (link); i++)
-    {
-      gchar *uri;
+  atk_value_get_current_value (atk_value, &value);
+  if (g_value_transform (&value, &svalue))
+    g_string_append_printf (string, "%*scurrent value: %s\n", depth, "", g_value_get_string (&svalue));
+  else
+    g_string_append_printf (string, "%*scurrent value: %s\n", depth, "", G_VALUE_TYPE_NAME (&value));
 
-      uri = atk_hyperlink_get_uri (link, i);
-      g_string_append_printf (string, " %s", uri);
-      g_free (uri);
-    }
+  g_value_reset (&value);
+  g_value_reset (&svalue);
 
-  g_string_append_c (string, '\n');
+  atk_value_get_minimum_increment (atk_value, &value);
+  if (g_value_transform (&value, &svalue))
+    g_string_append_printf (string, "%*sminimum increment: %s\n", depth, "", g_value_get_string (&svalue));
+  else
+    g_string_append_printf (string, "%*sminimum increment: %s\n", depth, "", G_VALUE_TYPE_NAME (&value));
+
+  g_value_reset (&value);
+  g_value_reset (&svalue);
 }
 
 static void
@@ -491,30 +474,26 @@ dump_atk_hyperlink_impl (AtkHyperlinkImpl *impl,
                          guint             depth,
                          GString          *string)
 {
-  AtkHyperlink *link;
+  AtkHyperlink *atk_link;
+  gint i;
 
   g_string_append_printf (string, "%*s<AtkHyperlinkImpl>\n", depth, "");
 
-  link = atk_hyperlink_impl_get_hyperlink (impl);
-  dump_atk_hyperlink (link, depth + DEPTH_INCREMENT, string);
-  g_object_unref (link);
-}
+  atk_link = atk_hyperlink_impl_get_hyperlink (impl);
 
-static void
-dump_atk_hypertext (AtkHypertext *hypertext,
-                    guint         depth,
-                    GString      *string)
-{
-  gint i;
-  AtkHyperlink *link;
+  g_string_append_printf (string, "%*sanchors:", depth, "");
 
-  g_string_append_printf (string, "%*s<AtkHypertext>\n", depth, "");
-
-  for (i = 0; i < atk_hypertext_get_n_links (hypertext); i++)
+  for (i = 0; i < atk_hyperlink_get_n_anchors (atk_link); i++)
     {
-      link = atk_hypertext_get_link (hypertext, i);
-      dump_atk_hyperlink (link, depth + DEPTH_INCREMENT, string);
+      gchar *uri;
+
+      uri = atk_hyperlink_get_uri (atk_link, i);
+      g_string_append_printf (string, " %s", uri);
+      g_free (uri);
     }
+  g_string_append_c (string, '\n');
+
+  g_object_unref (atk_link);
 }
 
 static void
@@ -605,7 +584,6 @@ dump_atk_table (AtkTable *table,
       g_string_append_printf (string, "%*s", depth + DEPTH_INCREMENT, "");
       for (j = 0; j < atk_table_get_n_columns (table); j++)
         {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
           int id = atk_table_get_index_at (table, i, j);
 
           obj = atk_object_ref_accessible_child (ATK_OBJECT (table), id);
@@ -616,60 +594,11 @@ G_GNUC_BEGIN_IGNORE_DEPRECATIONS
                                   atk_table_get_row_at_index (table, id) == i ? "✓" : "⚠",
                                   atk_table_get_column_at_index (table, id) == j ? "✓" : "⚠",
                                   get_name (obj));
-G_GNUC_END_IGNORE_DEPRECATIONS
         }
       g_string_append (string, "\n");
     }
 }
 
-static void
-dump_atk_table_cell (AtkTableCell *table_cell,
-                     guint     depth,
-                     GString  *string)
-{
-  gint i;
-  AtkObject *obj;
-  GPtrArray *cells;
-  gint row = -1, column = -1;
-
-  g_string_append_printf (string, "%*s<AtkTableCell>\n", depth, "");
-
-  obj = atk_table_cell_get_table (table_cell);
-  if (obj)
-    g_string_append_printf (string, "%*stable: %s\n", depth, "", get_name (obj));
-
-  cells = atk_table_cell_get_column_header_cells (table_cell);
-  if (cells)
-    {
-      for (i = 0; i < cells->len; i++)
-        {
-          obj = g_ptr_array_index (cells, i);
-          if (obj)
-            g_string_append_printf (string, "%*scolumn-header[%d]: %s\n", depth, "", i, get_name (obj));
-        }
-      g_ptr_array_free (cells, TRUE);
-    }
-
-  cells = atk_table_cell_get_row_header_cells (table_cell);
-  if (cells)
-    {
-      for (i = 0; i < cells->len; i++)
-        {
-          obj = g_ptr_array_index (cells, i);
-          if (obj)
-            g_string_append_printf (string, "%*srow-header[%d]: %s\n", depth, "", i, get_name (obj));
-        }
-      g_ptr_array_free (cells, TRUE);
-    }
-
-  g_string_append_printf (string, "%*scolumn-span: %d\n", depth, "", atk_table_cell_get_column_span (table_cell));
-  g_string_append_printf (string, "%*srow-span: %d\n", depth, "", atk_table_cell_get_row_span (table_cell));
-  if (atk_table_cell_get_position (table_cell, &row, &column))
-    {
-      g_string_append_printf (string, "%*sposition: %d %d\n", depth, "", row, column);
-    }
-}
-
 static void
 dump_accessible (AtkObject     *accessible,
                  guint          depth,
@@ -714,18 +643,12 @@ dump_accessible (AtkObject     *accessible,
   if (ATK_IS_HYPERLINK_IMPL (accessible))
     dump_atk_hyperlink_impl (ATK_HYPERLINK_IMPL (accessible), depth, string);
 
-  if (ATK_IS_HYPERTEXT (accessible))
-    dump_atk_hypertext (ATK_HYPERTEXT (accessible), depth, string);
-
   if (ATK_IS_STREAMABLE_CONTENT (accessible))
     dump_atk_streamable_content (ATK_STREAMABLE_CONTENT (accessible), depth, string);
 
   if (ATK_IS_TABLE (accessible))
     dump_atk_table (ATK_TABLE (accessible), depth, string);
 
-  if (ATK_IS_TABLE_CELL (accessible))
-    dump_atk_table_cell (ATK_TABLE_CELL (accessible), depth, string);
-
   for (i = 0; i < atk_object_get_n_accessible_children (accessible); i++)
     {
       AtkObject *child = atk_object_ref_accessible_child (accessible, i);
@@ -813,7 +736,7 @@ test_ui_file (GFile *file)
 
       if (diff && diff[0])
         {
-          g_printerr ("Contents don't match expected contents:\n%s", diff);
+          g_test_message ("Contents don't match expected contents:\n%s", diff);
           g_test_fail ();
           g_free (diff);
         }
@@ -909,7 +832,6 @@ parse_command_line (int *argc, char ***argv)
 {
   GError *error = NULL;
   GOptionContext *context;
-  gchar *schema_dir;
 
   context = g_option_context_new ("- run GTK accessibility tests");
   g_option_context_add_main_entries (context, test_args, NULL);
@@ -923,39 +845,15 @@ parse_command_line (int *argc, char ***argv)
 
   gtk_test_init (argc, argv);
 
-  schema_dir = g_test_build_filename (G_TEST_BUILT, "", NULL);
-  g_setenv ("GSETTINGS_SCHEMA_DIR", schema_dir, TRUE);
-  g_free (schema_dir);
-
-  /* gtk_test_init does not call setlocale(), so do it ourselves,
-   * since running in the C locale breaks some our fancy
-   * utf8 output.
-   */
-  setlocale (LC_ALL, "en_US.utf8");
-
   return TRUE;
 }
 
-static void
-fix_settings (void)
-{
-  /* Some settings can affect the output of the accessibility tests,
-   * so we take some steps to isolate us from the ambient environment.
-   */
-
-  g_object_set (gtk_settings_get_default (),
-                "gtk-dialogs-use-header", TRUE,
-                NULL);
-}
-
 int
 main (int argc, char **argv)
 {
   if (!parse_command_line (&argc, &argv))
     return 1;
 
-  fix_settings ();
-
   if (argc < 2)
     {
       const char *basedir;
@@ -963,9 +861,13 @@ main (int argc, char **argv)
 
       if (arg_base_dir)
         basedir = arg_base_dir;
+      else if (g_getenv ("srcdir"))
+        basedir = g_getenv ("srcdir");
       else
-        basedir = g_test_get_dir (G_TEST_DIST);
+        basedir = ".";
+        
       dir = g_file_new_for_path (basedir);
+      
       add_tests_for_files_in_directory (dir);
 
       g_object_unref (dir);
